obelisk.strategies.retry
========================

.. automodule:: obelisk.strategies.retry

   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      ExponentialBackoffStrategy
      ImmediateRetryStrategy
      NoRetryStrategy
      RetryEvaluator
      RetryStrategy
   